@@ -1,8 +1,8 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 The PHP Group                                |
+   | Copyright (c) 1997-2017 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -32,38 +32,40 @@ struct php_gz_stream_data_t	{
 	php_stream *stream;
 };
 
-static size_t php_gziop_read(php_stream *stream, char *buf, size_t count TSRMLS_DC)
+static size_t php_gziop_read(php_stream *stream, char *buf, size_t count)
 {
 	struct php_gz_stream_data_t *self = (struct php_gz_stream_data_t *) stream->abstract;
 	int read;
-	
+
+	/* XXX this needs to be looped for the case count > UINT_MAX */
 	read = gzread(self->gz_file, buf, count);
-	
+
 	if (gzeof(self->gz_file)) {
 		stream->eof = 1;
 	}
-		
-	return (read < 0) ? 0 : read;
+
+	return (size_t)((read < 0) ? 0 : read);
 }
 
-static size_t php_gziop_write(php_stream *stream, const char *buf, size_t count TSRMLS_DC)
+static size_t php_gziop_write(php_stream *stream, const char *buf, size_t count)
 {
 	struct php_gz_stream_data_t *self = (struct php_gz_stream_data_t *) stream->abstract;
 	int wrote;
 
+	/* XXX this needs to be looped for the case count > UINT_MAX */
 	wrote = gzwrite(self->gz_file, (char *) buf, count);
 
-	return (wrote < 0) ? 0 : wrote;
+	return (size_t)((wrote < 0) ? 0 : wrote);
 }
 
-static int php_gziop_seek(php_stream *stream, off_t offset, int whence, off_t *newoffs TSRMLS_DC)
+static int php_gziop_seek(php_stream *stream, zend_off_t offset, int whence, zend_off_t *newoffs)
 {
 	struct php_gz_stream_data_t *self = (struct php_gz_stream_data_t *) stream->abstract;
 
 	assert(self != NULL);
 
 	if (whence == SEEK_END) {
-		php_error_docref(NULL TSRMLS_CC, E_WARNING, "SEEK_END is not supported");
+		php_error_docref(NULL, E_WARNING, "SEEK_END is not supported");
 		return -1;
 	}
 	*newoffs = gzseek(self->gz_file, offset, whence);
@@ -71,11 +73,11 @@ static int php_gziop_seek(php_stream *stream, off_t offset, int whence, off_t *n
 	return (*newoffs < 0) ? -1 : 0;
 }
 
-static int php_gziop_close(php_stream *stream, int close_handle TSRMLS_DC)
+static int php_gziop_close(php_stream *stream, int close_handle)
 {
 	struct php_gz_stream_data_t *self = (struct php_gz_stream_data_t *) stream->abstract;
 	int ret = EOF;
-	
+
 	if (close_handle) {
 		if (self->gz_file) {
 			ret = gzclose(self->gz_file);
@@ -91,7 +93,7 @@ static int php_gziop_close(php_stream *stream, int close_handle TSRMLS_DC)
 	return ret;
 }
 
-static int php_gziop_flush(php_stream *stream TSRMLS_DC)
+static int php_gziop_flush(php_stream *stream)
 {
 	struct php_gz_stream_data_t *self = (struct php_gz_stream_data_t *) stream->abstract;
 
@@ -102,14 +104,14 @@ php_stream_ops php_stream_gzio_ops = {
 	php_gziop_write, php_gziop_read,
 	php_gziop_close, php_gziop_flush,
 	"ZLIB",
-	php_gziop_seek, 
+	php_gziop_seek,
 	NULL, /* cast */
 	NULL, /* stat */
 	NULL  /* set_option */
 };
 
-php_stream *php_stream_gzopen(php_stream_wrapper *wrapper, const char *path, const char *mode, int options, 
-							  char **opened_path, php_stream_context *context STREAMS_DC TSRMLS_DC)
+php_stream *php_stream_gzopen(php_stream_wrapper *wrapper, const char *path, const char *mode, int options,
+							  zend_string **opened_path, php_stream_context *context STREAMS_DC)
 {
 	struct php_gz_stream_data_t *self;
 	php_stream *stream = NULL, *innerstream = NULL;
@@ -117,19 +119,19 @@ php_stream *php_stream_gzopen(php_stream_wrapper *wrapper, const char *path, con
 	/* sanity check the stream: it can be either read-only or write-only */
 	if (strchr(mode, '+')) {
 		if (options & REPORT_ERRORS) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "cannot open a zlib stream for reading and writing at the same time!");
+			php_error_docref(NULL, E_WARNING, "cannot open a zlib stream for reading and writing at the same time!");
 		}
 		return NULL;
 	}
-	
+
 	if (strncasecmp("compress.zlib://", path, 16) == 0) {
 		path += 16;
 	} else if (strncasecmp("zlib:", path, 5) == 0) {
 		path += 5;
 	}
-	
+
 	innerstream = php_stream_open_wrapper_ex(path, mode, STREAM_MUST_SEEK | options | STREAM_WILL_CAST, opened_path, context);
-	
+
 	if (innerstream) {
 		php_socket_t fd;
 
@@ -150,7 +152,7 @@ php_stream *php_stream_gzopen(php_stream_wrapper *wrapper, const char *path, con
 
 			efree(self);
 			if (options & REPORT_ERRORS) {
-				php_error_docref(NULL TSRMLS_CC, E_WARNING, "gzopen failed");
+				php_error_docref(NULL, E_WARNING, "gzopen failed");
 			}
 		}
 
